@@ -112,6 +112,9 @@ html_document_base <- function(smart = TRUE,
     if (pandoc2.0() && is.null(metadata$title) && is.null(metadata$pagetitle))
       args <- c(args, "--metadata", paste0("pagetitle=", input_file))
 
+    # a lua filters added if pandoc2.0
+    args <- c(args, pandoc_lua_filters(c("pagebreak.lua", "latex-div.lua")))
+
     args
   }
 
